# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AgentMessage.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='AgentMessage.proto',
  package='communication',
  syntax='proto2',
  serialized_options=b'\n\024de.dlr.fame.protobufB\005Agent',
  serialized_pb=b'\n\x12\x41gentMessage.proto\x12\rcommunication\"\x99\x01\n\rProtoDataItem\x12\x12\n\ndataTypeId\x18\x01 \x02(\x05\x12\x11\n\tboolValue\x18\x02 \x03(\x08\x12\x10\n\x08intValue\x18\x03 \x03(\x05\x12\x11\n\tlongValue\x18\x04 \x03(\x03\x12\x12\n\nfloatValue\x18\x05 \x03(\x02\x12\x13\n\x0b\x64oubleValue\x18\x06 \x03(\x01\x12\x13\n\x0bstringValue\x18\x07 \x03(\t\"\xda\x01\n\nNestedItem\x12\x12\n\ndataTypeId\x18\x01 \x02(\x05\x12\x11\n\tboolValue\x18\x02 \x03(\x08\x12\x10\n\x08intValue\x18\x03 \x03(\x05\x12\x11\n\tlongValue\x18\x04 \x03(\x03\x12\x12\n\nfloatValue\x18\x05 \x03(\x02\x12\x13\n\x0b\x64oubleValue\x18\x06 \x03(\x01\x12\x13\n\x0bstringValue\x18\x07 \x03(\t\x12\x14\n\x0ctimeSeriesId\x18\x08 \x03(\x05\x12,\n\tcomponent\x18\t \x03(\x0b\x32\x19.communication.NestedItem\"\x93\x01\n\x0cProtoMessage\x12\x10\n\x08senderId\x18\x01 \x02(\x03\x12\x12\n\nreceiverId\x18\x02 \x02(\x03\x12.\n\x08\x64\x61taItem\x18\x03 \x03(\x0b\x32\x1c.communication.ProtoDataItem\x12-\n\nnestedItem\x18\x04 \x03(\x0b\x32\x19.communication.NestedItemB\x1d\n\x14\x64\x65.dlr.fame.protobufB\x05\x41gent'
)




_PROTODATAITEM = _descriptor.Descriptor(
  name='ProtoDataItem',
  full_name='communication.ProtoDataItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataTypeId', full_name='communication.ProtoDataItem.dataTypeId', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolValue', full_name='communication.ProtoDataItem.boolValue', index=1,
      number=2, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intValue', full_name='communication.ProtoDataItem.intValue', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longValue', full_name='communication.ProtoDataItem.longValue', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='floatValue', full_name='communication.ProtoDataItem.floatValue', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubleValue', full_name='communication.ProtoDataItem.doubleValue', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='communication.ProtoDataItem.stringValue', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=191,
)


_NESTEDITEM = _descriptor.Descriptor(
  name='NestedItem',
  full_name='communication.NestedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataTypeId', full_name='communication.NestedItem.dataTypeId', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolValue', full_name='communication.NestedItem.boolValue', index=1,
      number=2, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intValue', full_name='communication.NestedItem.intValue', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longValue', full_name='communication.NestedItem.longValue', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='floatValue', full_name='communication.NestedItem.floatValue', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubleValue', full_name='communication.NestedItem.doubleValue', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='communication.NestedItem.stringValue', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeSeriesId', full_name='communication.NestedItem.timeSeriesId', index=7,
      number=8, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component', full_name='communication.NestedItem.component', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=412,
)


_PROTOMESSAGE = _descriptor.Descriptor(
  name='ProtoMessage',
  full_name='communication.ProtoMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='senderId', full_name='communication.ProtoMessage.senderId', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiverId', full_name='communication.ProtoMessage.receiverId', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataItem', full_name='communication.ProtoMessage.dataItem', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nestedItem', full_name='communication.ProtoMessage.nestedItem', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=562,
)

_NESTEDITEM.fields_by_name['component'].message_type = _NESTEDITEM
_PROTOMESSAGE.fields_by_name['dataItem'].message_type = _PROTODATAITEM
_PROTOMESSAGE.fields_by_name['nestedItem'].message_type = _NESTEDITEM
DESCRIPTOR.message_types_by_name['ProtoDataItem'] = _PROTODATAITEM
DESCRIPTOR.message_types_by_name['NestedItem'] = _NESTEDITEM
DESCRIPTOR.message_types_by_name['ProtoMessage'] = _PROTOMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoDataItem = _reflection.GeneratedProtocolMessageType('ProtoDataItem', (_message.Message,), {
  'DESCRIPTOR' : _PROTODATAITEM,
  '__module__' : 'AgentMessage_pb2'
  # @@protoc_insertion_point(class_scope:communication.ProtoDataItem)
  })
_sym_db.RegisterMessage(ProtoDataItem)

NestedItem = _reflection.GeneratedProtocolMessageType('NestedItem', (_message.Message,), {
  'DESCRIPTOR' : _NESTEDITEM,
  '__module__' : 'AgentMessage_pb2'
  # @@protoc_insertion_point(class_scope:communication.NestedItem)
  })
_sym_db.RegisterMessage(NestedItem)

ProtoMessage = _reflection.GeneratedProtocolMessageType('ProtoMessage', (_message.Message,), {
  'DESCRIPTOR' : _PROTOMESSAGE,
  '__module__' : 'AgentMessage_pb2'
  # @@protoc_insertion_point(class_scope:communication.ProtoMessage)
  })
_sym_db.RegisterMessage(ProtoMessage)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
