# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Bundle.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AgentMessage_pb2 as AgentMessage__pb2
import Services_pb2 as Services__pb2
import InputFile_pb2 as InputFile__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Bundle.proto',
  package='mpi',
  syntax='proto2',
  serialized_options=b'\n\024de.dlr.fame.protobufB\003Mpi',
  serialized_pb=b'\n\x0c\x42undle.proto\x12\x03mpi\x1a\x12\x41gentMessage.proto\x1a\x0eServices.proto\x1a\x0fInputFile.proto\"\xc3\x02\n\nMpiMessage\x12\x33\n\rscheduledTime\x18\x01 \x01(\x0b\x32\x1c.communication.ScheduledTime\x12,\n\x06warmUp\x18\x02 \x01(\x0b\x32\x1c.communication.WarmUpMessage\x12/\n\x0b\x61\x64\x64ressBook\x18\x03 \x01(\x0b\x32\x1a.communication.AddressBook\x12\"\n\x05input\x18\x04 \x01(\x0b\x32\x13.iobinary.InputData\x12%\n\x06output\x18\x05 \x01(\x0b\x32\x15.communication.Output\x12,\n\x07message\x18\x06 \x01(\x0b\x32\x1b.communication.ProtoMessage\x12(\n\x05setup\x18\x07 \x01(\x0b\x32\x19.communication.ProtoSetup\"*\n\x06\x42undle\x12 \n\x07message\x18\x01 \x03(\x0b\x32\x0f.mpi.MpiMessageB\x1b\n\x14\x64\x65.dlr.fame.protobufB\x03Mpi'
  ,
  dependencies=[AgentMessage__pb2.DESCRIPTOR,Services__pb2.DESCRIPTOR,InputFile__pb2.DESCRIPTOR,])




_MPIMESSAGE = _descriptor.Descriptor(
  name='MpiMessage',
  full_name='mpi.MpiMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduledTime', full_name='mpi.MpiMessage.scheduledTime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warmUp', full_name='mpi.MpiMessage.warmUp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='addressBook', full_name='mpi.MpiMessage.addressBook', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='mpi.MpiMessage.input', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output', full_name='mpi.MpiMessage.output', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='mpi.MpiMessage.message', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='setup', full_name='mpi.MpiMessage.setup', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=398,
)


_BUNDLE = _descriptor.Descriptor(
  name='Bundle',
  full_name='mpi.Bundle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='mpi.Bundle.message', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=442,
)

_MPIMESSAGE.fields_by_name['scheduledTime'].message_type = Services__pb2._SCHEDULEDTIME
_MPIMESSAGE.fields_by_name['warmUp'].message_type = Services__pb2._WARMUPMESSAGE
_MPIMESSAGE.fields_by_name['addressBook'].message_type = Services__pb2._ADDRESSBOOK
_MPIMESSAGE.fields_by_name['input'].message_type = InputFile__pb2._INPUTDATA
_MPIMESSAGE.fields_by_name['output'].message_type = Services__pb2._OUTPUT
_MPIMESSAGE.fields_by_name['message'].message_type = AgentMessage__pb2._PROTOMESSAGE
_MPIMESSAGE.fields_by_name['setup'].message_type = Services__pb2._PROTOSETUP
_BUNDLE.fields_by_name['message'].message_type = _MPIMESSAGE
DESCRIPTOR.message_types_by_name['MpiMessage'] = _MPIMESSAGE
DESCRIPTOR.message_types_by_name['Bundle'] = _BUNDLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MpiMessage = _reflection.GeneratedProtocolMessageType('MpiMessage', (_message.Message,), {
  'DESCRIPTOR' : _MPIMESSAGE,
  '__module__' : 'Bundle_pb2'
  # @@protoc_insertion_point(class_scope:mpi.MpiMessage)
  })
_sym_db.RegisterMessage(MpiMessage)

Bundle = _reflection.GeneratedProtocolMessageType('Bundle', (_message.Message,), {
  'DESCRIPTOR' : _BUNDLE,
  '__module__' : 'Bundle_pb2'
  # @@protoc_insertion_point(class_scope:mpi.Bundle)
  })
_sym_db.RegisterMessage(Bundle)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
